use thiserror::Error;

#[derive (Error, Debug)]
pub enum ConfigError {
	#[error ("I/O error")]
	Io (#[from] std::io::Error),
	
	#[error ("UTF-8 decoding failed")]
	Utf8 (#[from] std::string::FromUtf8Error),
	
	#[error ("TOML parsing failed")]
	Toml (#[from] toml::de::Error),
	
	#[error ("base64 decoding failed")]
	Base64Decode (#[from] base64::DecodeError),
	
	#[error ("tripcode not 32 bytes after decoding")]
	TripcodeBadLength,
	
	#[error ("unknown config error")]
	Unknown,
}

// I'm not sure how important this is, but it was already in the code

#[derive (Error, Debug)]
pub enum ShuttingDownError {
	#[error ("Relay is shutting down")]
	ShuttingDown,
}

#[derive (Error, Debug)]
pub enum RelayError {
	#[error ("Handlebars template file error")]
	TemplateFile (#[from] handlebars::TemplateFileError),
}
